Index: include/v8.h |
diff --git a/include/v8.h b/include/v8.h |
index 1b65770d35e3fe98bf6f374b3df5b6c46b817ba6..19373a1398720ad1816df0dfd49ec5f8f88a86c0 100644 |
--- a/include/v8.h |
+++ b/include/v8.h |
@@ -6606,10 +6606,12 @@ class V8_EXPORT Context { |
V8_INLINE Local<Value> GetEmbedderData(int index); |
/** |
* Gets the exports object used by V8 extras. Extra natives get a reference |
* to this object and can use it to export functionality. |
*/ |
- Local<Object> GetExtrasExportsObject(); |
+ Local<Object> GetExtrasBindingObject(); |
/** |
* Sets the embedder data with the given index, growing the data as |
@@ -6606,10 +6606,12 @@ class V8_EXPORT Context { |
V8_INLINE Local<Value> GetEmbedderData(int index); |
/** |
- * Gets the exports object used by V8 extras. Extra natives get a reference |
- * to this object and can use it to export functionality. |
+ * Gets the binding object used by V8 extras. Extra natives get a reference |
+ * to this object and can use it to "export" functionality by adding |
+ * properties. Extra natives can also "import" functionality by accessing |
+ * properties added by the embedder using the V8 API. |
*/ |